import os
import json

# Load the dictionary
_dict = None

def _load_dict():
    global _dict
    if _dict is None:
        dict_path = os.path.join(os.path.dirname(__file__), 'dictionary.json')
        with open(dict_path, 'r', encoding='utf-8') as f:
            _dict = json.load(f)
    return _dict

def convert_chinese_to_vietnamese(text):
    """
    Convert Chinese text to Vietnamese using Sino-Vietnamese readings.
    
    Args:
        text (str): Chinese text to convert
        
    Returns:
        str: Vietnamese text with each character converted
    """
    d = _load_dict()
    result = []
    for char in text:
        if char in d:
            result.append(d[char])
        else:
            result.append(char)
    return ' '.join(result)


from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="cn2vn",
    version="0.1.1",
    author="jetaudio.media",
    author_email="jetaudio.media@gmail.com",
    description="A library to convert Chinese text to Vietnamese using Sino-Vietnamese readings",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jetaudio.media/cn2vn",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=[],
    include_package_data=True,
    package_data={
        'cn2vn': ['dictionary.json'],
    },
)